summaryrefslogtreecommitdiffstats
path: root/kbabel/kbabeldict/kbabeldictview.cpp
diff options
context:
space:
mode:
Diffstat (limited to 'kbabel/kbabeldict/kbabeldictview.cpp')
-rw-r--r--kbabel/kbabeldict/kbabeldictview.cpp6
1 files changed, 3 insertions, 3 deletions
diff --git a/kbabel/kbabeldict/kbabeldictview.cpp b/kbabel/kbabeldict/kbabeldictview.cpp
index 5346e758..18bb20ac 100644
--- a/kbabel/kbabeldict/kbabeldictview.cpp
+++ b/kbabel/kbabeldict/kbabeldictview.cpp
@@ -61,11 +61,11 @@
#include <kiconloader.h>
/*
* Constructs a KBabelDictView which is a child of 'tqparent', with the
* name 'name' and widget flags set to 'f'
*/
-KBabelDictView::KBabelDictView( TQWidget* tqparent, const char* name, WFlags fl )
- : TQWidget( tqparent, name, fl )
+KBabelDictView::KBabelDictView( TQWidget* parent, const char* name, WFlags fl )
+ : TQWidget( parent, name, fl )
{
TQVBoxLayout *mainLayout = new TQVBoxLayout(this);
mainLayout->setSpacing(KDialog::spacingHint());
@@ -61,11 +61,11 @@
#include <kiconloader.h>
/*
- * Constructs a KBabelDictView which is a child of 'tqparent', with the
+ * Constructs a KBabelDictView which is a child of 'parent', with the
* name 'name' and widget flags set to 'f'
*/